pub trait MappableType {
// Required method
fn get_mpr_type() -> mpr_type;
}Expand description
Marker trait for types that are bit-compatible with the libmapper C library.
If this trait is implemented on a type, that type can be passed to libmapper functions safely.
Use the get_mpr_type function to pass a type parameter to libmapper.
Required Methods
Sourcefn get_mpr_type() -> mpr_type
fn get_mpr_type() -> mpr_type
Get the mpr_type representing this rust type.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".